package model

import (
	"time"

	"go.mongodb.org/mongo-driver/bson/primitive"
)

// QueryType identifies key type
type QueryType string

// predefined query types
const (
	QueryTypePostcode QueryType = "postcode"
	QueryTypeFreeform QueryType = "freeform"
	QueryTypeUdprnURL QueryType = "udprnurl"
)

// Address is data model to store idealpostcodes.Address
// with ALL source fields, but different struct tags (bson).
type Address struct {
	PostTown             string  `bson:"post_town"`
	Street               string  `bson:"street"`
	Flat                 string  `bson:"flat"`
	Line1                string  `bson:"line_1"`
	Line2                string  `bson:"line_2"`
	Line3                string  `bson:"line_3"`
	BuildingName         string  `bson:"building_name"`
	BuildingNumber       string  `bson:"building_number"`
	SubBuildingName      string  `bson:"sub_building_name"`
	Country              string  `bson:"country"`
	County               string  `bson:"county"`
	AdministrativeCounty string  `bson:"administrative_county"`
	PostalCounty         string  `bson:"postal_county"`
	TraditionalCounty    string  `bson:"traditional_county"`
	District             string  `bson:"district"`
	Longitude            float64 `bson:"longitude"`
	Latitude             float64 `bson:"latitude"`
	Postcode             string  `bson:"postcode"`
}

// Results is the set of addresses keyed to given query
type Results struct {
	ID        primitive.ObjectID `bson:"_id,omitempty"`
	UpdatedAt time.Time          `bson:"updated_at"`
	Key       string             `bson:"key"`
	Addresses []*Address         `bson:"addresses"`
}
