// Package service provides implementation for address service
package service

import (
	"context"
	"fmt"

	address "gitlab.dcloud.tech/mashplace/backend/address/api"
	"gitlab.dcloud.tech/mashplace/backend/address/internal/model"
	"gitlab.dcloud.tech/mashplace/backend/address/pkg/idealpostcodes"
)

// Config for service implementation
type Config struct {
	Repository     model.Repository
	IdealPostcodes idealpostcodes.Client
}

// Service implementation
type Service interface {
	address.AddressServiceServer
}

func validateConfig(config *Config) error {
	if config == nil {
		return fmt.Errorf("invalid service config")
	}

	if config.Repository == nil {
		return fmt.Errorf("no repository in service config")
	}

	if config.IdealPostcodes == nil {
		return fmt.Errorf("no ideal postcodes client in service config")
	}

	return nil
}

// NewService returns new service instance
func NewService(ctx context.Context, config *Config) (Service, error) {
	err := validateConfig(config)
	if err != nil {
		return nil, err
	}

	srv := &serviceImpl{
		config: *config,
	}

	return srv, nil
}
