package service

import (
	"strings"

	address "gitlab.dcloud.tech/mashplace/backend/address/api"
	"gitlab.dcloud.tech/mashplace/backend/address/internal/model"
	"gitlab.dcloud.tech/mashplace/backend/address/pkg/idealpostcodes"
)

func (srv *serviceImpl) renderAddresses(ms []*model.Address) (addrs []*address.Address) {
	for _, m := range ms {
		addrs = append(addrs, srv.renderAddress(m))
	}

	return
}

func (srv *serviceImpl) renderAddress(m *model.Address) (addr *address.Address) {
	return &address.Address{
		Address:  renderJoin(m.Line1, m.Line2, m.Line3),
		Postcode: m.Postcode,
		Address1: m.Line1,
		Address2: m.Line2,
		Address3: m.Line3,
		Address4: "",
		Flat:     m.SubBuildingName,
		Building: m.BuildingNumber,
		Street:   m.Street,
		City:     m.PostTown,
		Gps: &address.Location{
			Longitude: m.Longitude,
			Latitude:  m.Latitude,
		},
		Country:              m.Country,
		PostTown:             m.PostTown,
		County:               m.County,
		AdministrativeCounty: m.County,
		PostalCounty:         m.PostalCounty,
		TraditionalCounty:    m.TraditionalCounty,
		District:             m.District,
	}
}

func (srv *serviceImpl) renderSuggestions(
	ms []*idealpostcodes.AutocompleteSuggestion,
) (suggestions []*address.AutocompleteSuggestion) {
	for _, m := range ms {
		suggestions = append(suggestions, srv.renderSuggestion(m))
	}

	return
}

func (srv *serviceImpl) renderSuggestion(m *idealpostcodes.AutocompleteSuggestion) *address.AutocompleteSuggestion {
	if m == nil {
		return nil
	}

	return &address.AutocompleteSuggestion{
		Suggestion: m.Suggestion,
		UdprnUrl:   m.UdprnURL,
	}
}

func renderJoin(ss ...string) string {
	var ps []string

	for _, s := range ss {
		p := strings.TrimSpace(s)

		if len(p) > 0 {
			ps = append(ps, p)
		}
	}

	return strings.Join(ps, " ")
}
